dlk.core.callbacks package
==========================

Submodules
----------

dlk.core.callbacks.checkpoint module
------------------------------------

.. automodule:: dlk.core.callbacks.checkpoint
   :members:
   :undoc-members:
   :show-inheritance:

dlk.core.callbacks.early\_stop module
-------------------------------------

.. automodule:: dlk.core.callbacks.early_stop
   :members:
   :undoc-members:
   :show-inheritance:

dlk.core.callbacks.lr\_monitor module
-------------------------------------

.. automodule:: dlk.core.callbacks.lr_monitor
   :members:
   :undoc-members:
   :show-inheritance:

dlk.core.callbacks.weight\_average module
-----------------------------------------

.. automodule:: dlk.core.callbacks.weight_average
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dlk.core.callbacks
   :members:
   :undoc-members:
   :show-inheritance:
